pub struct CommitFilter {
pub since: Option<String>,
pub until: Option<String>,
pub no_merges: bool,
}Expand description
The git log filters that affect which commits a source yields. Grouped so
they travel together and form part of the history cache key.
Fields
since: Option<String>until: Option<String>no_merges: boolTrait Implementations
Sourceimpl Clone for CommitFilter
impl Clone for CommitFilter
Sourcefn clone(&self) -> CommitFilter
fn clone(&self) -> CommitFilter
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CommitFilter
impl Debug for CommitFilter
Sourceimpl Default for CommitFilter
impl Default for CommitFilter
Sourcefn default() -> CommitFilter
fn default() -> CommitFilter
Returns the “default value” for a type. Read more
impl Eq for CommitFilter
Sourceimpl PartialEq for CommitFilter
impl PartialEq for CommitFilter
Sourcefn eq(&self, other: &CommitFilter) -> bool
fn eq(&self, other: &CommitFilter) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CommitFilter