Release

Struct Release 

pub struct Release {
    pub name: String,
    pub ts: i64,
}
A tagged release: a git tag name and the unix timestamp of the tag (the tag date for annotated tags, the commit date for lightweight tags). Used to draw release markers on the timeline for single-repository runs.

Fields

name: Stringts: i64